darkhistory.electrons.ics.BE_integrals.F0 — DarkHistory documentation

# darkhistory.electrons.ics.BE_integrals.F0

`darkhistory.electrons.ics.BE_integrals.` `F0`(a, b, epsrel=0)

  Definite integral of 1/[(exp(x) - 1)].

  Parameters: | a : ndarray Lower limit of integration. Can be either 1D or 2D. b : ndarray Upper limit of integration. Can be either 1D or 2D. err : float Error associated with series expansion. If zero, then the error is not computed.
  Returns: | float The resulting integral.

#### Previous topic

darkhistory.electrons.ics.BE_integrals

#### Next topic

darkhistory.electrons.ics.BE_integrals.F1

### This Page

Show Source